@@ -1,15 +1,52 @@
 """Base class for param setter logic for table data diff"""
 
-from typing import List, Optional, Set, Union
+from typing import List, Optional, Set, Type, Union
 from urllib.parse import urlparse
 
 from metadata.data_quality.validations.models import Column, TableParameter
 from metadata.generated.schema.entity.data.table import Table
 from metadata.generated.schema.entity.services.databaseService import DatabaseService
+from metadata.generated.schema.entity.services.serviceType import ServiceType
+from metadata.ingestion.connections.connection import BaseConnection
 from metadata.ingestion.source.connections import get_connection
 from metadata.profiler.orm.registry import Dialects
 from metadata.utils import fqn
 from metadata.utils.collections import CaseInsensitiveList
+from metadata.utils.importer import get_module_dir, import_from_module
+
+
+# TODO: Refactor to avoid the circular import that makes us unable to use the BaseSpec class and the helper methods.
+# Using the specs class method causes circular import as TestSuiteInterface
+# imports RuntimeParameterSetter
+class ServiceSpecPatch:
+    def __init__(self, service_type: ServiceType, source_type: str):
+        self.service_type = service_type
+        self.source_type = source_type
+        self._service_spec = None
+
+    @property
+    def service_spec(self):
+        if self._service_spec is None:
+            self._service_spec = self.get_for_source()
+        return self._service_spec
+
+    def get_for_source(self):
+        return import_from_module(
+            "metadata.{}.source.{}.{}.{}.ServiceSpec".format(  # pylint: disable=C0209
+                "ingestion",
+                self.service_type.name.lower(),
+                get_module_dir(self.source_type),
+                "service_spec",
+            )
+        )
+
+    def get_data_diff_class(self) -> Type["BaseTableParameter"]:
+        return import_from_module(self.service_spec.data_diff)
+
+    def get_connection_class(self) -> Optional[Type[BaseConnection]]:
+        if self.service_spec.connection_class:
+            return import_from_module(self.service_spec.connection_class)
+        return None
 
 
 class BaseTableParameter:
@@ -22,7 +59,7 @@ class BaseTableParameter:
         key_columns,
         extra_columns,
         case_sensitive_columns,
-        service_url: Optional[str],
+        service_url: Optional[Union[str, dict]],
     ) -> TableParameter:
         """Getter table parameter for the table diff test.
 
@@ -63,29 +100,38 @@ class BaseTableParameter:
         ).replace("___SERVICE___.__DATABASE__.", "")
 
     @staticmethod
-    def get_service_connection_config(
-        db_service: DatabaseService,
+    def _get_service_connection_config(
+        service_connection_config,
     ) -> Optional[Union[str, dict]]:
-        """Get the service connection config.
-
-        Args:
-            db_service (DatabaseService): The database service entity
         """
-        if db_service.connection.config.type.value.lower() == "trino":
-            from metadata.ingestion.source.database.trino.connection import (  # pylint: disable=import-outside-toplevel
-                get_connection_dict,
-            )
-
-            return get_connection_dict(db_service.connection.config)
-        return (
-            str(get_connection(db_service.connection.config).url)
-            if db_service.connection.config
-            else None
+        Get the connection dictionary for the service.
+        """
+        service_spec_patch = ServiceSpecPatch(
+            ServiceType.Database, service_connection_config.type.value.lower()
         )
 
+        try:
+            connection_class = service_spec_patch.get_connection_class()
+            if not connection_class:
+                return (
+                    str(get_connection(service_connection_config).url)
+                    if service_connection_config
+                    else None
+                )
+            connection = connection_class(service_connection_config)
+            return connection.get_connection_dict()
+        except (ValueError, AttributeError, NotImplementedError):
+            return (
+                str(get_connection(service_connection_config).url)
+                if service_connection_config
+                else None
+            )
+
     @staticmethod
     def get_data_diff_url(
-        db_service: DatabaseService, table_fqn, override_url: Optional[str] = None
+        db_service: DatabaseService,
+        table_fqn,
+        override_url: Optional[Union[str, dict]] = None,
     ) -> Union[str, dict]:
         """Get the url for the data diff service.
 
@@ -97,13 +143,13 @@ class BaseTableParameter:
         Returns:
             str: The url for the data diff service
         """
-
         source_url = (
-            BaseTableParameter.get_service_connection_config(db_service)
+            BaseTableParameter._get_service_connection_config(
+                db_service.connection.config
+            )
             if not override_url
             else override_url
         )
-
         if isinstance(source_url, dict):
             source_url["driver"] = source_url["driver"].split("+")[0]
             return source_url
