@@ -14,11 +14,17 @@ Constants required for dbt
 
 from enum import Enum
 
+from metadata.generated.schema.entity.data.apiEndpoint import APIEndpoint
+from metadata.generated.schema.entity.data.dashboard import Dashboard
+from metadata.generated.schema.entity.data.mlmodel import MlModel
+
 DBT_RUN_RESULT_DATE_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
 
 # Based on https://schemas.getdbt.com/dbt/manifest/v7/index.html
 REQUIRED_MANIFEST_KEYS = ["name", "schema", "resource_type"]
 
+REQUIRED_EXPOSURE_KEYS = ["name", "meta", "type", "resource_type", "sources"]
+
 # Based on https://schemas.getdbt.com/dbt/catalog/v1.json
 REQUIRED_CATALOG_KEYS = ["name", "type", "index"]
 
@@ -84,7 +90,6 @@ REQUIRED_NODE_KEYS = {
     "language",
 }
 
-
 NONE_KEYWORDS_LIST = ["none", "null"]
 
 DBT_CATALOG_FILE_NAME = "catalog.json"
@@ -148,6 +153,8 @@ class DbtCommonEnum(Enum):
     OWNER = "owner"
     NODES = "nodes"
     SOURCES = "sources"
+    EXPOSURE = "exposure"
+    EXPOSURES = "exposures"
     SOURCES_FILE = "sources_file"
     SOURCE = "source"
     RESOURCETYPE = "resource_type"
@@ -156,3 +163,12 @@ class DbtCommonEnum(Enum):
     RESULTS = "results"
     TEST_SUITE_NAME = "test_suite_name"
     DBT_TEST_SUITE = "DBT_TEST_SUITE"
+
+
+# DBT Supports more types of exposures but only these map nicely
+# https://docs.getdbt.com/docs/build/exposures#available-properties
+ExposureTypeMap = {
+    "dashboard": {"entity_type": Dashboard, "entity_type_name": "dashboard"},
+    "ml": {"entity_type": MlModel, "entity_type_name": "mlmodel"},
+    "application": {"entity_type": APIEndpoint, "entity_type_name": "apiEndpoint"},
+}
