@@ -1,3 +1,4 @@
+from metadata.ingestion.source.database.postgres.connection import PostgresConnection
 from metadata.ingestion.source.database.postgres.lineage import PostgresLineageSource
 from metadata.ingestion.source.database.postgres.metadata import PostgresSource
 from metadata.ingestion.source.database.postgres.usage import PostgresUsageSource
@@ -7,4 +8,5 @@ ServiceSpec = DefaultDatabaseSpec(
     metadata_source_class=PostgresSource,
     lineage_source_class=PostgresLineageSource,
     usage_source_class=PostgresUsageSource,
+    connection_class=PostgresConnection,
 )
