@@ -19,6 +19,7 @@ from collections import defaultdict
 from datetime import datetime
 from typing import Dict, Iterable, List, Optional, Union
 
+from networkx import DiGraph
 from pydantic import BaseModel, ConfigDict, Field
 from sqlalchemy.engine import Engine
 
@@ -41,6 +42,12 @@ from metadata.ingestion.lineage.sql_lineage import get_lineage_by_query
 from metadata.ingestion.models.ometa_lineage import OMetaLineageRequest
 from metadata.ingestion.models.topology import Queue
 from metadata.ingestion.ometa.ometa_api import OpenMetadata
+from metadata.utils.filters import (
+    filter_by_database,
+    filter_by_schema,
+    filter_by_stored_procedure,
+)
+from metadata.utils.helpers import pprint_format_object
 from metadata.utils.logger import ingestion_logger
 from metadata.utils.stored_procedures import get_procedure_name_from_call
 from metadata.utils.time_utils import datetime_to_timestamp
@@ -79,6 +86,17 @@ class ProcedureAndQuery(BaseModel):
     model_config = ConfigDict(populate_by_name=True)
 
 
+class ProcedureAndProcedureGraph(BaseModel):
+    """
+    Model to hold the procedure and its graph
+    """
+
+    model_config = ConfigDict(arbitrary_types_allowed=True)
+
+    procedure: StoredProcedure
+    graph: DiGraph
+
+
 class StoredProcedureLineageMixin(ABC):
     """
     The full flow is:
@@ -136,6 +154,17 @@ class StoredProcedureLineageMixin(ABC):
                     )
                 )
 
+        queries_count_per_procedure = {
+            procedure_name: len(queries)
+            for procedure_name, queries in queries_dict.items()
+        }
+        logger.info(
+            f"Count of queries executed for stored procedures: {sum(queries_count_per_procedure.values())}"
+        )
+        logger.info(
+            f"Count of queries per stored procedure: {pprint_format_object(queries_count_per_procedure)}"
+        )
+
         return queries_dict
 
     @staticmethod
@@ -165,11 +194,31 @@ class StoredProcedureLineageMixin(ABC):
             query_type=query_by_procedure.query_type,
             query_text=query_by_procedure.query_text,
         ):
+            graph = None
+            if self.source_config.enableTempTableLineage:
+                if not self.procedure_graph_map.get(procedure.fullyQualifiedName.root):
+                    # Map to store the directed graph for each procedure with its FQN as key
+                    self.procedure_graph_map[
+                        procedure.fullyQualifiedName.root
+                    ] = ProcedureAndProcedureGraph(procedure=procedure, graph=DiGraph())
+
+                graph = self.procedure_graph_map.get(
+                    procedure.fullyQualifiedName.root
+                ).graph
+
             self.stored_procedure_query_lineage = True
+            # Prepare service names for lineage processing
+            service_names = [self.service_name]
+            if (
+                self.source_config.processCrossDatabaseLineage
+                and self.source_config.crossDatabaseServiceNames
+            ):
+                service_names.extend(self.source_config.crossDatabaseServiceNames)
+
             for either_lineage in get_lineage_by_query(
                 self.metadata,
                 query=query_by_procedure.query_text,
-                service_name=self.service_name,
+                service_names=service_names,
                 database_name=query_by_procedure.query_database_name,
                 schema_name=query_by_procedure.query_schema_name,
                 dialect=ConnectionTypeDialectMapper.dialect_of(
@@ -177,6 +226,7 @@ class StoredProcedureLineageMixin(ABC):
                 ),
                 timeout_seconds=self.source_config.parsingTimeoutLimit,
                 lineage_source=LineageSource.QueryLineage,
+                graph=graph,
             ):
                 if (
                     either_lineage.left is None
@@ -289,6 +339,25 @@ class StoredProcedureLineageMixin(ABC):
             or []
         ):
             if procedure:
+                if (
+                    filter_by_database(
+                        self.source_config.databaseFilterPattern,
+                        procedure.database.name,
+                    )
+                    or filter_by_schema(
+                        self.source_config.schemaFilterPattern,
+                        procedure.databaseSchema.name,
+                    )
+                    or filter_by_stored_procedure(
+                        self.source_config.storedProcedureFilterPattern,
+                        procedure.name.root,
+                    )
+                ):
+                    self.status.filter(
+                        procedure.name.root,
+                        "Stored Procedure Filtered Out",
+                    )
+                    continue
                 logger.debug(f"Processing Lineage for [{procedure.name}]")
                 for query_by_procedure in (
                     queries_dict.get(procedure.name.root.lower()) or []
