@@ -14,7 +14,7 @@ Helpers module for db sources
 """
 
 import traceback
-from typing import Iterable
+from typing import Iterable, List, Union
 
 from metadata.generated.schema.api.lineage.addLineage import AddLineageRequest
 from metadata.generated.schema.entity.data.table import Table
@@ -50,21 +50,25 @@ def get_host_from_host_port(uri: str) -> str:
 def get_view_lineage(
     view: TableView,
     metadata: OpenMetadata,
-    service_name: str,
+    service_names: Union[str, List[str]],
     connection_type: str,
     timeout_seconds: int = LINEAGE_PARSING_TIMEOUT,
 ) -> Iterable[Either[AddLineageRequest]]:
     """
     Method to generate view lineage
+    Now supports cross-database lineage by accepting a list of service names.
     """
+    if isinstance(service_names, str):
+        service_names = [service_names]
     table_name = view.table_name
     schema_name = view.schema_name
     db_name = view.db_name
+    schema_fallback = False
     view_definition = view.view_definition
     table_fqn = fqn.build(
         metadata,
         entity_type=Table,
-        service_name=service_name,
+        service_name=service_names[0],  # Use first service for table entity lookup
         database_name=db_name,
         schema_name=schema_name,
         table_name=table_name,
@@ -88,30 +92,33 @@ def get_view_lineage(
         if table_entity.serviceType == DatabaseServiceType.Postgres:
             # For Postgres, if schema is not defined, we need to use the public schema
             schema_name = PUBLIC_SCHEMA
+            schema_fallback = True
 
         if lineage_parser.source_tables and lineage_parser.target_tables:
             yield from get_lineage_by_query(
                 metadata,
                 query=view_definition,
-                service_name=service_name,
+                service_names=service_names,
                 database_name=db_name,
                 schema_name=schema_name,
                 dialect=dialect,
                 timeout_seconds=timeout_seconds,
                 lineage_source=LineageSource.ViewLineage,
+                schema_fallback=schema_fallback,
             ) or []
 
         else:
             yield from get_lineage_via_table_entity(
                 metadata,
                 table_entity=table_entity,
-                service_name=service_name,
+                service_names=service_names,
                 database_name=db_name,
                 schema_name=schema_name,
                 query=view_definition,
                 dialect=dialect,
                 timeout_seconds=timeout_seconds,
                 lineage_source=LineageSource.ViewLineage,
+                schema_fallback=schema_fallback,
             ) or []
     except Exception as exc:
         logger.debug(traceback.format_exc())
